@@ -20,7 +20,7 @@ setClass("ca.jo", representation(x="ANY",
                                  ZK="matrix",
                                  type="character",
                                  model="character",
-                                 const="logical",
+                                 ecdet="character",
                                  lag="integer",
                                  P="integer",
                                  season="ANY",
@@ -48,7 +48,7 @@ setClass("cajo.test", representation(Z0="matrix",
                                      A="ANY",
                                      B="ANY",
                                      type="character",
-                                     const="logical",
+                                     ecdet="character",
                                      teststat="numeric",
                                      pval="vector",
                                      lambda="vector",
